/*------------------------------------------------------------------------------
    GALE. Fine-grained parallel Genetic Algorithms for Data Mining.
    Copyright (C) 2002  Xavier Llor <xllora@illigal.ge.uiuc.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
------------------------------------------------------------------------------*/


package edu.uiuc.ge.illigal.gale.data;

import java.util.Random;

/**
 * This class is a view over a certain InstanceMemory.
 *
 * @author  Xavier Llor&agrave; &lt;<a href="mailto:xllora@illigal.ge.uiuc.edu">xllora@illigal.ge.uiuc.edu</a>&gt;
 * @version 0.9alpha
 * @since 0.9alpha
 */

public class RandomSamplingDataView
implements OrderedSet
{
	/** The Ordered data set*/
	private OrderedSet osData;

	/** The number of instances randomly pick */
	private int iSize;

   /** The maximum number of instances available */
	private int iMaxSize;

   /** The proportion of instances randomly pick */
	private float fProportion;

   /** The random number generator object */
	private Random rnd;


   //---------------------------------------------------------------------

	/** Builds a view over the OrderSet given.
	 *
    *  @param os The ordered set that contains the data
	 * @param fProp The proportion of os instances to show
    * @param r The random number generator
    */
   public RandomSamplingDataView ( OrderedSet os, float fProp, Random r )
   {
		osData      = os;
		fProportion = fProp;
	   iSize       = (int)(fProp*os.getSize());
      iMaxSize    = os.getSize();
      rnd         = r;
   }

   //---------------------------------------------------------------------

	// OrderedSet implementation
   public Instance getInstance ( int iPos )
	{
		if ( iPos>=0 && iPos<iSize )
			return osData.getInstance(rnd.nextInt(iMaxSize));
      else
			return null;
	}

   //---------------------------------------------------------------------

   // OrderedSet implementation
	public int getSize ()
   {
		return iSize;
	}

   //---------------------------------------------------------------------
}
